
/**********************************************************************
 
	Copyright (C) 2003 Hirohisa MORI <joshua@nichibun.ac.jp>
 
	This program is free software; you can redistribute it 
	and/or modify it under the terms of the GLOBALBASE 
	Library General Public License (G-LGPL) as published by 

	http://www.globalbase.org/
 
	This program is distributed in the hope that it will be 
	useful, but WITHOUT ANY WARRANTY; without even the 
	implied warranty of MERCHANTABILITY or FITNESS FOR A 
	PARTICULAR PURPOSE.

**********************************************************************/



#ifndef ___PRI_LEVEL_H___
#define ___PRI_LEVEL_H___
#define PRI_LOG			0

#define PRI_RCACHE		1
#define PRI_XL_ACCEPT		1

#define PRI_AGENT		1
#define PRI_IPC_TASK		1


#define PRI_RADAR_FETCH		2
#define PRI_FETCH		2

#define PRI_FETCH_RADAR		3

#define PRI_FETCH_STRONG	4
#define PRI_FETCH_STRONG_RES_MATRIX	4


#define PRI_V_RECONFIG		2
#define PRI_QUIT		4

#define PRI_LS_TASK		3

#define PRI_XL_RELAY		4
#define PRI_XL_FRONT		4
#define PRI_TR			3

#define PRI_TICK		3
#define PRI_BL			3
#define PRI_NETWORK		3
#define PRI_PARSE		5
#define PRI_GC			5

#define PRI_LOCK		3

#define PRI_HTMLDB		3
#define PRI_TICK_CLOSE		3
#define PRI_WRITE_BUF		3
#define PRI_TICK_STRONG		3
#define PRI_XL_TICK		3

#define PRI_FETCH_MOST_STRONG	3

#define PRI_MATRIX_DRAW			3
#define PRI_DRAW_EXIT		4
#define PRI_REDRAW		4
#define PRI_START_DRAW		4
#define PRI_DRAW		4

#define PRI_SLEEP_WAIT		5
#define PRI_QUEUE		5
#define PRI_USER_INTERFACE	5
#define PRI_V_QUEUE		5

#define PRI_TOOLKIT		5

#endif
